@@ -1,5 +1,3 @@
-require v5.10;
-
 package Module::Extract::VERSION;
 use strict;
 
@@ -11,11 +9,11 @@ use vars qw($VERSION);
 
 use Carp qw(carp);
 
-$VERSION = '1.10_01';
+$VERSION = '1.01';
 
 =head1 NAME
 
-Module::Extract::VERSION - Extract a module version safely
+Module::Extract::VERSION - Extract a module version without running code
 
 =head1 SYNOPSIS
 
@@ -31,7 +29,7 @@ Module::Extract::VERSION - Extract a module version safely
 
 This module lets you pull out of module source code the version number
 for the module. It assumes that there is only one C<$VERSION>
-in the file and the entire C<$VERSION> statement is on the same line.
+in the file.
 
 =cut
 
@@ -43,8 +41,7 @@ in the file and the entire C<$VERSION> statement is on the same line.
 
 Given a module file, return the module version. This works just like
 C<mldistwatch> in PAUSE. It looks for the single line that has the
-C<$VERSION> statement, extracts it, evals it in a Safe compartment,
-and returns the result.
+C<$VERSION> statement, extracts it, evals it, and returns the result.
 
 In scalar context, it returns just the version as a string. In list
 context, it returns the list of:
@@ -73,7 +70,7 @@ sub parse_version_safely # stolen from PAUSE's mldistwatch, but refactored
 		}
 	
 	my $in_pod = 0;
-	my( $sigil, $var, $version, $line_number, $rhs );
+	my( $sigil, $var, $version, $line_number );
 	while( <$fh> ) 
 		{
 		$line_number++;
@@ -82,27 +79,12 @@ sub parse_version_safely # stolen from PAUSE's mldistwatch, but refactored
 		$in_pod = /^=(?!cut)/ ? 1 : /^=cut/ ? 0 : $in_pod;
 		next if $in_pod || /^\s*#/;
 
-		next unless /
-			(?<sigil>
-				[\$*]
-			)
-			(?<identifier>
-				(?<package>
-					[\w\:\']*
-				)
-				\b
-				VERSION
-			)
-			\b
-			.*?
-			\=
-			(?<rhs>
-				.*
-			)
-			/x;
-		( $sigil, $var, $rhs ) = @+{ qw(sigil var rhs) };
+		next unless /([\$*])(([\w\:\']*)\bVERSION)\b.*\=/;
+		( $sigil, $var ) = ( $1, $2 );
 		
-		$version = $class->_eval_version( $_, @+{ qw(sigil var rhs) } );
+		#print STDERR "Got $1 and $2\n";
+		
+		$version = $class->_eval_version( $_, $sigil, $var );
 
 		last;
 		}
@@ -114,17 +96,28 @@ sub parse_version_safely # stolen from PAUSE's mldistwatch, but refactored
 
 sub _eval_version
 	{
-	my( $class, $line, $sigil, $var, $rhs ) = @_;
+	my $class = shift;
+	
+	my( $line, $sigil, $var ) = @_;
+	
+	#print STDERR "_eval_version called with @_\n";
+	
+	my $eval = qq{ 
+		package ExtUtils::MakeMaker::_version;
 
-	require Safe;
-	require version;
-	local $^W = 0;
+		local $sigil$var;
+		\$$var=undef; do {
+			$line
+			}; \$$var
+		};
+		
+	my $version = do {
+		local $^W = 0;
+		no strict;
+		eval( $eval );
+		};
 
-	my $s = Safe->new;
-	$s->share_from('main', ['*version::']);
-	$s->share_from('version', ['&qv']);
-	$s->reval('$VERSION = ' . $rhs);
-	my $version = $s->reval('$VERSION');
+	#print STDERR "Version is $version\n";
 
 	return $version;
 	}
